@@ -13,11 +13,11 @@ use lib "$FindBin::Bin/../lib";
 
 use Protocol::DBus::Client;
 
-my $dbus = $> ? Protocol::DBus::Client::login_session() : Protocol::DBus::Client::system();
+my $dbus = Protocol::DBus::Client::system();
 
 $dbus->preserve_variant_signatures(1);
 
-$dbus->initialize();
+$dbus->do_authn();
 
 my $got_response;
 
@@ -28,10 +28,11 @@ $dbus->send_call(
     signature => 's',
     member => 'GetAll',
     body => ['org.freedesktop.DBus'],
-)->then( sub {
-    $got_response = 1;
-    print "got getall response\n";
-    print Dumper shift;
-} );
+    on_return => sub {
+        $got_response = 1;
+        print "got getall response\n";
+        print Dumper shift;
+    },
+);
 
 $dbus->get_message() while !$got_response;
