@@ -127,6 +127,20 @@ sub authn_pending_send {
 
 #----------------------------------------------------------------------
 
+=head2 $yn = I<OBJ>->supports_unix_fd()
+
+Boolean that indicates whether this client supports UNIX FD passing.
+
+=cut
+
+sub supports_unix_fd {
+    my ($self) = @_;
+
+    return $self->{'_authn'}->negotiated_unix_fd();
+}
+
+#----------------------------------------------------------------------
+
 =head2 $msg = I<OBJ>->get_message()
 
 Same as in the base class, but for clients the initial “Hello” message and
@@ -146,6 +160,17 @@ sub get_message {
     return undef;
 }
 
+=head2 $name = I<OBJ>->get_connection_name()
+
+Returns the name of the connection. This must only be called after at least
+one message is received; if it is called before then, an exception is thrown.
+
+=cut
+
+sub get_connection_name {
+    return $_[0]->{'_connection_name'} || die 'No connection name known yet!';
+}
+
 # undocumented
 sub new {
     my ($class, %opts) = @_;
